@@ -41,6 +41,10 @@ public:
         TrustSignatureDomain,
     };
 
+    enum ModelRoles {
+        SignerKeyIdRole = Qt::UserRole,
+    };
+
     explicit UserIDListModel(QObject *parent = nullptr);
     ~UserIDListModel() override;
 
@@ -48,9 +52,9 @@ public:
 
 public:
     GpgME::UserID userID(const QModelIndex &index) const;
-    QVector<GpgME::UserID> userIDs(const QModelIndexList &indexes) const;
+    QList<GpgME::UserID> userIDs(const QModelIndexList &indexes) const;
     GpgME::UserID::Signature signature(const QModelIndex &index) const;
-    QVector<GpgME::UserID::Signature> signatures(const QModelIndexList &indexes) const;
+    QList<GpgME::UserID::Signature> signatures(const QModelIndexList &indexes) const;
     void enableRemarks(bool value);
 
 public Q_SLOTS:
